nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

IntCtrl

Struct IntCtrl 

#[repr(transparent)]
pub struct IntCtrl(pub u32);
Interrupt Control Register

Tuple Fields

0: u32

Implementations

Source

impl IntCtrl

pub const fn hw_err(&self) -> IntCtrlHwErr

Bit position that can be cleared if corresponding bit of INT_STATUS has been asserted.

pub const fn set_hw_err(&mut self, val: IntCtrlHwErr)

Bit position that can be cleared if corresponding bit of INT_STATUS has been asserted.

pub const fn ent_val(&self) -> IntCtrlEntVal

Same behavior as bit 0 above.

pub const fn set_ent_val(&mut self, val: IntCtrlEntVal)

Same behavior as bit 0 above.

pub const fn frq_ct_fail(&self) -> IntCtrlFrqCtFail

Same behavior as bit 0 above.

pub const fn set_frq_ct_fail(&mut self, val: IntCtrlFrqCtFail)

Same behavior as bit 0 above.