#[repr(transparent)]pub struct IntMask(pub u32);Expand description
Mask Register
Tuple Fields
0: u32Implementations
Sourceimpl IntMask
impl IntMask
Sourcepub const fn hw_err(&self) -> IntMaskHwErr
pub const fn hw_err(&self) -> IntMaskHwErr
Bit position that can be cleared if corresponding bit of INT_STATUS has been asserted.
Sourcepub const fn set_hw_err(&mut self, val: IntMaskHwErr)
pub const fn set_hw_err(&mut self, val: IntMaskHwErr)
Bit position that can be cleared if corresponding bit of INT_STATUS has been asserted.
Sourcepub const fn ent_val(&self) -> IntMaskEntVal
pub const fn ent_val(&self) -> IntMaskEntVal
Same behavior as bit 0 above.
Sourcepub const fn set_ent_val(&mut self, val: IntMaskEntVal)
pub const fn set_ent_val(&mut self, val: IntMaskEntVal)
Same behavior as bit 0 above.
Sourcepub const fn frq_ct_fail(&self) -> IntMaskFrqCtFail
pub const fn frq_ct_fail(&self) -> IntMaskFrqCtFail
Same behavior as bit 0 above.
Sourcepub const fn set_frq_ct_fail(&mut self, val: IntMaskFrqCtFail)
pub const fn set_frq_ct_fail(&mut self, val: IntMaskFrqCtFail)
Same behavior as bit 0 above.